@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import abc
 import copy
+import functools
 import typing
 
 from mutwo import core_constants
@@ -59,6 +60,13 @@ class Event(abc.ABC):
         if not condition(start, end):
             raise core_utilities.InvalidStartAndEndValueError(start, end)
 
+    @functools.cached_property
+    def _event_to_metrized_event(self):
+        # XXX: import in method to avoid circular import error
+        return __import__(
+            "mutwo.core_converters"
+        ).core_converters.EventToMetrizedEvent()
+
     # ###################################################################### #
     #                           public properties                            #
     # ###################################################################### #
@@ -385,9 +393,9 @@ class Event(abc.ABC):
 T = typing.TypeVar("T", bound=Event)
 
 
-# FIXME(This Event can be initialised (no abstract error),
-#  maybe abc.update_abstractmethods can help, but we have to wait
-#  until mutwo migrates to python 3.10)
+# FIXME(This Event can be initialised (no abstract error).
+# Please see the following issue for comparison:
+#   https://bugs.python.org/issue35815
 class ComplexEvent(Event, abc.ABC, list[T], typing.Generic[T]):
     """Abstract Event-Object, which contains other Event-Objects."""
 
@@ -630,7 +638,7 @@ class ComplexEvent(Event, abc.ABC, list[T], typing.Generic[T]):
         [event.mutate_parameter(parameter_name, function) for event in self]
 
     @core_utilities.add_copy_option
-    def filter(  # type: ignore
+    def remove_by(  # type: ignore
         self, condition: typing.Callable[[Event], bool]
     ) -> ComplexEvent[T]:
         """Condition-based deletion of child events.
@@ -649,7 +657,7 @@ class ComplexEvent(Event, abc.ABC, list[T], typing.Generic[T]):
         >>> simultaneous_event = core_events.SimultaneousEvent(
             [core_events.SimpleEvent(1), core_events.SimpleEvent(3), core_events.SimpleEvent(2)]
         )
-        >>> simultaneous_event.filter(lambda event: event.duration > 2)
+        >>> simultaneous_event.remove_by(lambda event: event.duration > 2)
         >>> simultaneous_event
         SimultaneousEvent([SimpleEvent(duration = 3)])
         """
@@ -737,10 +745,7 @@ class ComplexEvent(Event, abc.ABC, list[T], typing.Generic[T]):
     # ###################################################################### #
 
     def metrize(self, mutate: bool = True) -> ComplexEvent:
-        # XXX: import in method to avoid circular import error
-        metrized_event = __import__(
-            "mutwo.core_converters"
-        ).core_converters.EventToMetrizedEvent()(self)
+        metrized_event = self._event_to_metrized_event(self)
         if mutate:
             self.tempo_envelope = metrized_event.tempo_envelope
             self[:] = metrized_event[:]
